"""Top-level package for Notebook-like Executables."""

__author__ = """Matthias Hölzl"""
__email__ = "tc@xantira.com"
__version__ = "0.2.2"
